import os
import logbook
from logbook import Logger, TimedRotatingFileHandler
from logbook.more import ColorizedStderrHandler

DATETIME_FORMAT = "%Y-%m-%d %H:%M:%S.00"


def handler_log_formatter(record, handler):
    log = "[{dt}][{level}][{filename}][{func_name}][{lineno}] {msg}".format(
        dt=record.time,
        level=record.level_name,
        filename=os.path.split(record.filename)[-1],
        func_name=record.func_name,
        lineno=record.lineno,
        msg=record.message,
    )
    return log


std_handler = ColorizedStderrHandler(bubble=True)
std_handler.formatter = handler_log_formatter

LOG_DIR = os.path.join('log')
if not os.path.exists(LOG_DIR):
    os.makedirs(LOG_DIR)

file_handler = TimedRotatingFileHandler(
    os.path.join(LOG_DIR, '%s.log' % 'runtime'),
    date_format='%Y%m%d',
    bubble=True,
    backup_count=31,
    rollover_format='{basename}.{timestamp}{ext}')
file_handler.formatter = handler_log_formatter

logger = Logger()


def init_logger():
    logbook.set_datetime_format("local")
    logger.handlers = []
    logger.handlers.append(std_handler)
    logger.handlers.append(file_handler)


init_logger()



import base64

import demjson

import util.dates as dt
from intranet_infiltrator.infiltrator import Infiltrator
from util.logger import logger


class Infiltrator31ms(Infiltrator):

    def __init__(self,
                 username: str,
                 password: str):
        self.username = username
        self.password = base64.b64encode(password.encode('utf-8'))

    def infiltrate(self):
        payload = {
            'userVO.userid': self.username,
            'userVO.pwd': self.password
        }
        r = self.session.post('http://31ms.abc/privmng/To31msAuthenticationAction_usaplogin.action', data=payload)
        if r.status_code == 200:
            if r.text.index('个人信息') > 0:
                logger.info('[{}] - [{}] -> success infiltrate to 31ms '.format(self.username, self.password))

        return self

    def aim_job_list(self):
        r = self.session.post('http://31ms.abc/job/JobInfoAction_countAllJobRecord.action')
        if r.status_code == 200:
            json_obj = demjson.decode(r.text)
            job_list = json_obj['rows']
            for row in job_list:
                num_job = row['jobnum']
                name_job = row['jobTypeCN']
                if num_job != '' and int(num_job) > 0:
                    logger.info('{0} -> {1}'.format(name_job, num_job))
            return job_list

    def aim_routine_job_list(self):
        payload = {
            'start': '0',
            'limit': '100',
            'routInfoVO.setDate_Start': '',
            'routInfoVO.setDate_End': '',
            'routInfoVO.workType': '',
            'routInfoVO.workContent': '',
            'routInfoVO.jobStatus': '',
            'total': ''
        }
        r = self.session.post('http://31ms.abc/job/RoutInfoAction_findRoutInfoByWhere.action', data=payload)
        if r.status_code == 200:
            json_obj = demjson.decode(r.text)
            job_list = json_obj['rows']
            return job_list

    def obliterate_routine_job(self, routine_id, work_id):
        logger.info('{0} -> {1} aimed ...'.format(routine_id, work_id))
        payload = {
            'routRecordVO.workRequest': '',
            'routRecordVO.workDate': dt.to_current_month_end(),
            'habit': '已完成',
            'routRecordVO.workNote': '已完成',
            'routRecordVO.routId': routine_id,
            'routRecordVO.exitFlag': '0',
            'routRecordVO.Flag': dt.to_current_month_end(),
            'routRecordVO.workTipContent': '',
            'routRecordVO.workTipContent2': '',
            'routRecordVO.workTipContent3': work_id
        }
        r = self.session.post('http://31ms.abc/job/RoutRecordAction_submitPerWorkContent.action', data=payload)
        if r.status_code == 200:
            logger.info(r.json())
            logger.info('{0} -> {1} obliterated ...'.format(routine_id, work_id))

    def obliterate_routine_jobs(self):
        for routine in self.aim_routine_job_list():
            self.obliterate_routine_job(routine['routID'], routine['workID'])



import datetime
import time
from datetime import timedelta


def to_now():
    return datetime.datetime.now()


def to_current_timestamp():
    return int(time.time()) * 1000


def to_date_relative(d, delta):
    return d + timedelta(days=delta)


def to_string(d, f):
    return d.strftime(f)


def to_days_diff(d1, d2):
    return (d1 - d2).days


def to_date(s, f):
    return datetime.datetime.strptime(s, f)


def to_days_diff_f(d1, d2, f):
    return to_days_diff(to_date(d1, f), to_date(d2, f))


def to_last_month_end(f):
    d = datetime.date(day=1,
                      month=datetime.datetime.now().month,
                      year=datetime.datetime.now().year) - timedelta(days=1)
    return to_string(d, f)


def to_current_month_begin():
    return datetime.datetime.now().strftime('%Y%m01')


def to_current_month_end():
    return (to_date(to_current_month_begin(), "%Y%m%d") + datetime.timedelta(days=1)) .strftime('%Y%m%d')
